/*************************************************************************
  (c) Copyright.  Digital Equipment Corporation, 1995.  All Rights
  Reserved.

  Permission is hereby granted to use, copy, modify, or enhance this 
  software freely, as long as the foregoing copyright of Digital Equipment
  Corporation and this notice are retained on the software.  This 
  software may not be distributed or sublicensed for a fee.  Digital      
  makes this software available "AS IS" and without warranties of any
  kind.  
 *************************************************************************/

/*
* Module Name:
*   svc_info.c
*   
* Abstract:
*  Implement functions related to svc information structures.
*
* Authors:
*  JAD - John A. DeNisco
*
* Modification History:
*  Date       Name  Description
*  08-Mar-95  JAD   Created/taken from svc.c.
*
* Description:
*  Generally the svc_info structures are used, to pass information to and
*  from the connection manager and the svc interface. The svc interface is
*  found in cm_svc.h.  This files implements the functions that are used to
*  initialize and build these structures.
*
*/

/* Includes required by driver interface                          */

#include "g_types.h"       /* Driver type definitions             */
#include "codes.h"         /* Error codes                         */
#include "utl.h"           /* System utilities                    */
#include "utl_os.h"        /* Operating system specific utilities */
#include "atm.h"           /* ATM definitions                     */
#include "system.h"        /* System definitions                  */
#include "svc_info.h"      /* Svc information structures          */

/* Used only to keep the compiler happy */

struct sBuf{int dummy;};
struct ss_buffer{int dummy;};
struct umMib{int dummy;};
struct ss_queue{int dummy;};

/*++
* =====================
* = svcinit_conn_info =
* =====================
*
* Overview:
*  This function initilizes the connection information structure.
*  Initilization simply involves setting all the present flags to
*  "not present", and setting the called and calling party address bytes
*  to 0.
*
--*/

void svcinit_conn_info (CONN_INFO *p_svc_conn_info)
   {
   }

/*++
* =======================
* = svcinit_conn_status =
* =======================
*
* Overview:
*  This function initilizes the connection status structure.
*  Initilization simply involves setting all the present flags to
*  "not present".
*
--*/

void svcinit_conn_status (CONN_STATUS *p_svc_conn_status)
   {
   }

/*++
* ========================
* = svcinit_release_info =
* ========================
*
* Overview:
*  This function initilizes the release information structure.
*  Initilization simply involves setting all the present flags to
*  "not present".
*
--*/

void svcinit_release_info (RELEASE_INFO *p_svc_release_info)
   {
   }

/*++
* ========================
* = svcinit_add_pty_info =
* ========================
*
* Overview:
*  This function initilizes the add party information structure.
*  Initilization simply involves setting all the present flags to
*  "not present", and setting the called and calling party address
*  bytes to 0.
--*/

void svcinit_add_pty_info (ADD_PTY_INFO *p_svc_add_pty_info)
   {
   }

/*++
* ==========================
* = svcinit_add_pty_status =
* ==========================
*
* Overview:
*  This function initilizes the add party status structure.
*  Initilization simply involves setting all the present flags to 
*  "not present".
*
--*/

void svcinit_add_pty_status (ADD_PTY_STATUS *p_svc_add_pty_status)
   {
   }

/*++
* =========================
* = svcinit_drop_pty_info =
* =========================
*
* Overview:
*  This function initilizes the drop party information structure.
*  Initilization simply involves setting all the present flags to
*  "not present".
*
--*/

void svcinit_drop_pty_info (DROP_PTY_INFO  *p_svc_drop_pty_info)
   {
   }

/*++
* =======================================
* = conn_info_called_party_address_copy =
* =======================================
*
* Overview:
*  Copy the called party address from the conn_info block into the
*  p_called_addr structure.
*
--*/

STATUS conn_info_called_party_address_copy (CONN_INFO *p_conn_info,
                                            ADDR_ATM  *p_called_addr)
   {
   }

/*++
* ========================================
* = conn_info_calling_party_address_copy =
* ========================================
*
* Overview:
*  Copy the calling party address from the conn_info block into the
*  p_called_addr structure.
*
--*/

STATUS conn_info_calling_party_address_copy (CONN_INFO *p_conn_info,
                                             ADDR_ATM  *p_calling_addr)
   {
   }

/*++
* ======================
* = conn_info_qos_copy =
* ======================
*
* Overview:
* Copy the QOS info from the conn_info block into the QOS structure. Note
* that the QOS structure is not related to any Trillium structure.
*
--*/

STATUS conn_info_qos_copy (CONN_INFO  *p_conn_info,
                         QOS        *p_qos)
   {
   }

/*++
* ========================
* = svc_conn_info_id_get =
* ========================
*
* Overview:
*  Extract the VPI and VCI from the conn_info block.
*
--*/

STATUS svc_conn_info_id_get (CONN_INFO *p_conn_info,
                             UINT8     *p_vpi,
                             UINT16    *p_vci)
   {
   }

/*++
* ==========================
* = svc_conn_status_id_get =
* ==========================
*
* Overview:
*  Extract the VPI and VCI from the conn_status block.
*
--*/

STATUS svc_conn_status_id_get (CONN_STATUS *p_conn_status,
                               UINT8       *p_vpi,
                               UINT16      *p_vci)
   {
   }

/*++
* ==================================
* = svc_conn_info_conn_sts_convert =
* ==================================
*
* Overview:
*  This function takes the information contained in a CONN_INFO structure
*  and copies it to a CONN_STATUS structure.
*
--*/

void svc_conn_info_conn_sts_convert (CONN_INFO   *p_conn_info,
                                     CONN_STATUS *p_conn_status)
   {
   }

/*++
* ==========================
* = svc_release_info_make =
* ==========================
*
* Overview:
*  This function generates a RELEASE_INFO block appropriate to the indicated
*  error condition.
*
--*/

void svc_release_info_make (int           code,
                            RELEASE_INFO *p_release_info)
   {
   }
